@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # FILE:
 # Instance.py
@@ -46,6 +46,7 @@ from gnue.designer.base.TemplateParser import WizardRunner
 from PrimaryToolBar import PrimaryToolBar
 from gnue.designer import VERSION, PACKAGE
 from ModuleSupport import SupportedModules
+from gnue.designer.base import Goat
 
 TITLE=PACKAGE
 
@@ -111,6 +112,9 @@ class BaseInstance(wxFrame, EventController):
     wxFrame.__init__(self, NULL, -1, "")
     EventController.__init__(self)
 
+    icon = Goat.getGoatIcon()
+    self.SetIcon(icon)
+
     # During startup, we will cache all events
     # so we can execute them when everything has
     # been initialized.
@@ -130,10 +134,10 @@ class BaseInstance(wxFrame, EventController):
     # Set up the Undo/Redo Manager
     UndoManager(self)
 
-
-    self._isdirty = 0
-    self._makeBackup = 1
-    self._isNew = 1
+    self.wizardName = ""
+    self._isdirty = False
+    self._makeBackup = True
+    self._isNew = True
 
     self._app = app
     self.connections = app.connections
@@ -176,7 +180,7 @@ class BaseInstance(wxFrame, EventController):
     else:
 
       if not os.access (location, os.R_OK):
-        self.Show(1)
+        self.Show(True)
         if wxMessageDialog(self,
           _('The requested file does not exist.\n') +
           _('Do you want to create this file?') +
@@ -189,7 +193,7 @@ class BaseInstance(wxFrame, EventController):
         self.makeDirty()
 
       elif not os.access (location, os.W_OK):
-        self.Show(1)
+        self.Show(True)
         if wxMessageDialog(self, \
           _('The requested file is Read Only.\n') +
           _('To save any changes, you will \n') +
@@ -202,16 +206,14 @@ class BaseInstance(wxFrame, EventController):
         self.__loadFromFile(location)
 
     self.statusbar = self.CreateStatusBar()
-    self.SetStatusText('Welcome to GNUe Designer -- Do not expose to direct sunlight, do not feed after midnight, and do not get wet.')
+    self.SetStatusText(_('Welcome to GNUe Designer -- Do not expose to direct sunlight, do not feed after midnight, and do not get wet.'))
     self.menubar = MenuBar(self)
-    self.toolbar = PrimaryToolBar(self, self)
-    self.SetToolBar(self.toolbar)
 
 
-    StartupStatus(_('Inventorying Document Objects'))
+    gStartupStatus(_('Inventorying Document Objects'))
     self.rootObject.walk(self.__inventory)
 
-    StartupStatus(_('Creating User Interface'))
+    gStartupStatus(_('Creating User Interface'))
 
     # Create the supplemental tools
     self._toolCache = []
@@ -220,15 +222,18 @@ class BaseInstance(wxFrame, EventController):
     self._initMenu()
     self.initMenu()
 
+    self.createWizards()
     self.createTools()
     self._initTools()
-    self.createWizards()
-    self.initToolBar()
 
     # Finalize menu bar
     self.menubar.finalize()
     self._app.mru.addMenu(self.menubar.getMenu('File|Open Recent|'), self)
 
+    self.toolbar = PrimaryToolBar(self, self)
+    self.SetToolBar(self.toolbar)
+    self.initToolBar()
+
     # TODO: This is a hack to disable any menu items
     # TODO: for actions we've yet to implement
     for action in ('RequestRevert','RequestRedo','RequestCopy',
@@ -301,7 +306,7 @@ class BaseInstance(wxFrame, EventController):
        ('Help', 'RequestAbout', _("&About GNUe Designer"), None, _("More information about GNUe Designer"), 900),
      ):
       self.menubar.addAction(location, text, event,
-                      grouping, canDisable=1,
+                      grouping, canDisable=True,
                       icon=None, hotkey=hotkey, help=help)
 
     # Add supported tools to File|New
@@ -388,7 +393,7 @@ class BaseInstance(wxFrame, EventController):
   def __createEmptyInstance(self, style):
     self.rootObject = self.loadEmpty(style)
     self.makeClean()
-    self._isNew = 1
+    self._isNew = True
 
 
   #
@@ -412,7 +417,7 @@ class BaseInstance(wxFrame, EventController):
   # Mark our form as "dirty" (unsaved changes)
   def makeDirty(self):
     if not self._isdirty:
-      self._isdirty = 1
+      self._isdirty = True
       if self._path == "":
         self.SetTitle( TITLE + _(" - <New %s> *") % self.properties.nickname)
       else:
@@ -565,10 +570,10 @@ class BaseInstance(wxFrame, EventController):
     fileHandle.write('<?xml version="1.0" encoding="%s"?>\n\n' % \
            gConfig('textEncoding'))
 
-    fileHandle.write('<!--  %s (%s)\n      Saved on: %s  -->\n\n' \
-       % (TITLE, VERSION, \
-          time.strftime("%Y-%m-%d %H:%M:%S",time.localtime(time.time()))))
-    fileHandle.write(self.rootObject.dumpXML(treeDump=1).encode(gConfig('textEncoding')))
+    fileHandle.write('<!--  %s (%s)\n%s      Saved on: %s  -->\n\n' \
+       % (TITLE, VERSION, (len(self.wizardName) and ("      Created by " + self.wizardName + "\n") or ""),\
+          time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))))
+    fileHandle.write(self.rootObject.dumpXML(treeDump=True).encode(gConfig('textEncoding')))
     fileHandle.close()
 
     self._app.mru.addLocation(location)
@@ -578,9 +583,8 @@ class BaseInstance(wxFrame, EventController):
 
   def __OnConnectTo(self, event):
     conn = event.connection
-    tempDO = self.connections.getDataObject(conn, 'object')
     try:
-      self.connections.requestConnection(tempDO, conn)
+      tempDO = self.connections.getConnection(conn, 'object')
       self.dispatchEvent('ConnectionEstablished',connection=conn)
       self.dispatchEvent('Disable:Connect:%s' % conn)
     except:
@@ -699,8 +703,8 @@ class BaseInstance(wxFrame, EventController):
           self.wizardRunner(template, self)
           self.menubar.addAction(location=location, text=translation,
                                   event='Wizard:%s' % template['BaseID'],
-                                  grouping=grouping, canDisable=1,
-                                  eventdata={'template':template})
+                                  grouping=grouping, canDisable=True,
+                                  eventdata={'template':template}, help=template['Description'])
       except ValueError:
         continue
 
