@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # FILE:
 # DataSourceEditor.py
@@ -367,13 +367,13 @@ class ToolBar (wxToolBar):
     self.deleteButtonId = wxNewId()
 
     self.AddSimpleTool(self.addButtonId,
-        wxImage(iamges_dir+gConfig('tb_insert'),
+        wxImage(images_dir+gConfig('tb_insert'),
                 wxBITMAP_TYPE_PNG).ConvertToBitmap(),
         _("Create Data Source"),
         _("Create a new data source"))
 
     self.AddSimpleTool(self.deleteButtonId,
-        wxImage(iamges_dir+gConfig('tb_delete'),
+        wxImage(images_dir+gConfig('tb_delete'),
                 wxBITMAP_TYPE_PNG).ConvertToBitmap(),
         _("Delete Data Source"),
         _("Delete the currently selected data source"))
