@@ -1,5 +1,7 @@
 #
-# This file is part of GNU Enterprise.
+# Copyright 2001-2005 Free Software Foundation
+#
+# This file is part of GNU Enterprise
 #
 # GNU Enterprise is free software; you can redistribute it
 # and/or modify it under the terms of the GNU General Public
@@ -16,15 +18,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
-#
-# FILE:
-# TriggerEditor.py
-#
-# DESCRIPTION:
-#
-# NOTES:
-#
+# $Id: TriggerEditor.py 7148 2005-03-10 12:45:16Z kilo $
 
 
 from wxPython.wx import *
@@ -52,10 +46,8 @@ class TriggerEditor (ToolBase):
 
     if USE_STC:
       EditorCtrl = PythonEditorControl
-      print "1"
     else:
       EditorCtrl = FallbackPythonEditorControl
-      print "2"
     self.editor = EditorCtrl(self,-1, pos=wxPoint(0,32))
     self.editor.InEditMode = 0
 
@@ -260,7 +252,7 @@ class TriggerEditor (ToolBase):
 
 try:
 
- if int(gConfig('ForceSimpleEditor',section="designer")):
+ if gConfig('ForceSimpleEditor',section="designer") == True:
    raise ImportError
 
  from wxPython.stc import *
@@ -327,7 +319,7 @@ try:
 
     # TODO: A lot of this should be configurable
 
-    if int(gConfig('ColorizeCode',section="designer")):
+    if gConfig('ColorizeCode',section="designer") == True:
 
       # Global default styles for all languages
       self.StyleSetSpec(wxSTC_STYLE_DEFAULT,     "face:%(helv)s,size:%(size)d" % faces)
@@ -371,8 +363,7 @@ try:
     EVT_KEY_DOWN(self, self.OnKeyPressed)
 
 
-  def OnKeyPressed(self, event):    
-    print "press"
+  def OnKeyPressed(self, event):
     key = event.KeyCode()
     if key == 32 and event.ControlDown():
       pos = self.GetCurrentPos()
@@ -415,7 +406,7 @@ try:
     if self.InEditMode:
       self.instance.makeDirty()
       self.parent.object._children[0]._content = self.GetText()
-      
+
   def OnUpdateUI(self, evt):
     # check for matching braces
     braceAtCaret = -1
