@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # FILE:
 # DisplayDropTarget.py
@@ -436,7 +436,9 @@ class DisplayDropTarget(wxPyDropTarget):
         new['Char:width'] = maxWidth
         instance.rootObject._layout.Char__width = maxWidth
 
-      instance.dispatchEvent('ObjectModified',
+      if sys.platform != 'win32':
+        # if you dispatch this event on win32, it will crash :(
+        instance.dispatchEvent('ObjectModified',
              object=instance.rootObject._layout,
              old=old,
              new=new,
