@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # FILE:
 # LayoutEditor.py
@@ -35,6 +35,7 @@ from wxPython.wx import *
 from gnue.common.apps import GDebug
 from gnue.forms import GFObjects
 from gnue.forms.uidrivers.wx import UIdriver as UIwxpython
+from gnue.forms.uidrivers.wx.common import wxEncode
 from gnue.designer.base.PopupMenu import PageMenu
 from gnue.designer.base.TemplateParser import TemplateParser
 from gnue.designer.base.ToolBase import *
@@ -90,6 +91,7 @@ class LayoutEditor (ToolBase):
     self.notebook = wxNotebook(self, -1, pos=wxPoint(4, 4), size=wxSize(32,32))
     self.backcolor = wxWHITE
 
+    EVT_RIGHT_DOWN(self.notebook, self.onRightDown)
     EVT_NOTEBOOK_PAGE_CHANGED(self,self.notebook.GetId(), self.OnPageSelected)
     EVT_SIZE(self, self.OnSize)
 
@@ -112,6 +114,7 @@ class LayoutEditor (ToolBase):
                        'ObjectDeleted'       : self.onDeleteObject,
                        'LayoutEditor:ZoomIn' : self.zoomIn,
                        'LayoutEditor:ZoomOut': self.zoomOut,
+                       'LayoutEditor:AutoArrange' : self.onAutoArrange,
                        'LayoutEditor:FocusOrder': self.beginFocusOrder,
                        'Cancel:LayoutEditor:FocusOrder': self.endFocusOrder,
                        'LayoutEditor:Prepositioning': self.beginPrePositioningTemplate,
@@ -162,7 +165,8 @@ class LayoutEditor (ToolBase):
       self.workspace = wxPanel(self.workspacescroll,-1)
       self.workspace.SetBackgroundColour(self.backcolor)
 
-      self.notebook.AddPage(self.workspacescroll,object.name)
+      self.notebook.AddPage(self.workspacescroll, wxEncode(object.name))
+
       object.__workspace = self.workspace
       self.drawPage(object)
     if object._type == 'GFBlock':
@@ -414,8 +418,8 @@ class LayoutEditor (ToolBase):
       self.charWidth = maxWidth+maxLeading
       self.charHeight = maxHeight+maxDescent
 
-      self.borderPercentage = (float(gConfig('borderPercentage')) / 100)
-      self.textPercentage = (float(gConfig('textPercentage')) / 100)
+      self.borderPercentage = (float(gConfig('borderPercentage', section='designer')) / 100)
+      self.textPercentage = (float(gConfig('textPercentage', section='designer')) / 100)
 
       self.widgetWidth = int(self.charWidth * self.borderPercentage)
       self.widgetHeight = int(self.charHeight * self.borderPercentage) + 3
@@ -795,6 +799,9 @@ class LayoutEditor (ToolBase):
     self.dispatchEvent('LayoutEditor:Select')
     self.__wizardrunner.positioned_run(x=x, y=y, width=width, height=height)
 
+  def onAutoArrange(self, event):
+    self.dispatchEvent('LayoutEditor:FocusOrder')
+    self.reorderfocus.autoArrange()
 
   def beginFocusOrder(self, event):
     mode = self.mode
@@ -840,6 +847,16 @@ class LayoutEditor (ToolBase):
       self.dispatchEvent('Cancel:LayoutEditor:Prepositioning')
     self.dispatchEvent('LayoutEditor:Select')
 
+  def onRightDown(self, event):
+    """
+    Show "Add page" popup menu
+    """
+    pt = event.GetPositionTuple()
+    wxPyTypeCast(event.GetEventObject(),'wxWindow') \
+        .PopupMenu(self.page._popupMenu, pt)
+    event.Skip()
+
+
 class PrepositioningTimer(wxTimer):
     def __init__(self, method, *args, **params):
       self.__method = method
