@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # FILE:
 # Workspace.py
@@ -368,8 +368,8 @@ class Workspace(wxPanel):
       self.charWidth = maxWidth+maxLeading
       self.charHeight = maxHeight+maxDescent
 
-      self.borderPercentage = (float(gConfig('borderPercentage')) / 100)
-      self.textPercentage = (float(gConfig('textPercentage')) / 100)
+      self.borderPercentage = (float(gConfig('borderPercentage', section='designer')) / 100)
+      self.textPercentage = (float(gConfig('textPercentage', section='designer')) / 100)
 
       self.widgetWidth = int(self.charWidth * self.borderPercentage)
       self.widgetHeight = int(self.charHeight * self.borderPercentage) + 3
