@@ -17,7 +17,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # FILE:
 # forms/wizards/CreateWebForm.py
@@ -33,14 +33,14 @@
 #         -  add step to choose 'included image orgin' (subdir: "img/",
 #            topdir: "/img/", "other host...
 #         -  option to deactivate/activate Statusbar, Buttonbar, a Menu
-#         -  option to switch between different layout styles 
-# 
+#         -  option to switch between different layout styles
+#
 #     b) Code Creation
 #         - use em/en sizes for absolute positioning (drawback:depend on font size)
 #         - menu bar creation
 #         - add GFBox, GFImage types
 #         - add more GFEntry styles (f.e. dropdown)
-#         - add tooltips to Toolbar Icons 
+#         - add tooltips to Toolbar Icons
 #         - support multiple rows
 #         - create page switching tab (if enabled)
 #         - add code for a login/logged out window on top of the form (done)
@@ -109,7 +109,7 @@ class CreateWebFormWizard(FormTemplate):
 
       content = [WizardText('This will build a dynamic web form writen in '+
                             'HTML and Javascript. For more information '+
-                            'confer to "jsclient/INSTALL.TXT".\n\n '), 
+                            'confer to "jsclient/INSTALL.TXT".\n\n '),
                  WizardInput('file',label='File Name:',required=1,size=20),
                  WizardText('\n\nChoose default cell size (in Pixel):'),
                  WizardInput('cellwidth',label='Cell Width  :',
@@ -128,21 +128,21 @@ class CreateWebFormWizard(FormTemplate):
 
       if self.variables['file'][-5:]!=".html":
         self.variables['file']+=".html"
-        
+
       self.Xraster=int(self.variables['cellwidth'])
       self.Yraster=int(self.variables['cellheight'])
       self.baseline=int(self.Yraster*6/35)
       self.fontsize=int(self.Yraster*18/35)
       self.lineheight=self.Yraster
       self.fontsize_entry=int(self.Yraster*16/35)
-      
+
       self.variables['encoding']=gConfig('textEncoding')
       choices=(('iso8859-1','Western'),
                ('utf-8','Unicode'),
                ('big5','Trad. Chinese' ),
                ('gb2312','Simpl. Chinese' ),
                ('jis','Japanese' ))
-        
+
       content = [WizardText('The web form will be stored in the file '+
                             ('%s.\n\n' % self.variables['file'])),
                  WizardText('Form Size: %sx%s => ' % \
@@ -157,7 +157,7 @@ class CreateWebFormWizard(FormTemplate):
                  'content': content,
                  'prev': '0',
                  'next': None }
-    
+
 
   ###############
   #
@@ -197,13 +197,13 @@ class CreateWebFormWizard(FormTemplate):
                ' charset=%s">\n  </HEAD>\n' % charset)
 
     dest.write('<BODY onLoad="setup();form.run();" onUnload="form.close();">')
-    
+
     if hasattr(self,'showtitle'):
       dest.write('<H1>%s</H1>' % title)
 
-    # write javascript include    
+    # write javascript include
     dest.write('<SCRIPT src="vcXMLRPC.js"></SCRIPT>\n' +\
-               '<SCRIPT src="gnue-forms.js"></SCRIPT>\n')    
+               '<SCRIPT src="gnue-forms.js"></SCRIPT>\n')
     # write datasource data, trigger information etc.
     dest.write(self.buildCode(self.form))
 
@@ -218,7 +218,7 @@ class CreateWebFormWizard(FormTemplate):
     if hasattr(layout,"tabbed") and len(layout.tabbed)>0:
       # Create Page tabs
       pos=0
-      for child in layout._children:        
+      for child in layout._children:
         if child._type=="GFPage":
           dest.write(self.addPageTab(child.name,pos))
           pos+=200
@@ -227,9 +227,9 @@ class CreateWebFormWizard(FormTemplate):
 
 
     dest.write(self.addBackground())
-      
-    
-    for child in layout._children:      
+
+
+    for child in layout._children:
       if child._type=="GFPage":
         ## dest.write("<h2>%s</H2>" % child.name)
         dest.write('<DIV id="%s_page">' % child.name)
@@ -240,7 +240,7 @@ class CreateWebFormWizard(FormTemplate):
 
     if self.statusBar:
       dest.write(self.addStatusBar())
-    
+
     dest.write(self.addLoginDialog())
     dest.write("<BODY></HTML>")
     dest.close()
@@ -268,7 +268,7 @@ class CreateWebFormWizard(FormTemplate):
       outp+="dts._setParent(form);\n"
       outp+="dts.name='%s';\n" % obj.name
       outp+="dts.table='%s';\n" % obj.table
-      
+
       if hasattr(obj,"order_by"):
         outp+="dts.order_by='%s';\n" % obj.order_by
 
@@ -286,9 +286,9 @@ class CreateWebFormWizard(FormTemplate):
 
       if hasattr(obj,"cache"):
         outp+="dts.cache=%s;\n" % obj.cache
-        
+
       outp+="dts.connection='%s';\n\n" % obj.connection
-      
+
 
     if obj._type=="GFLogic":
       pass
@@ -300,10 +300,10 @@ class CreateWebFormWizard(FormTemplate):
       outp+="blk.datasource='%s';\n\n" % obj.datasource
 
     if obj._type=='GFField':
-      outp+="field = new GFField(blk);\n" 
-      outp+="field._setParent(blk);\n"             
+      outp+="field = new GFField(blk);\n"
+      outp+="field._setParent(blk);\n"
       outp+="field.name='%s';\n" % obj.name
-      if hasattr(obj,"field"):	
+      if hasattr(obj,"field"):
         outp+="field.field='%s';\n" % obj.field
       else:
         outp+="field.field='%s';\n" % obj.name
@@ -339,7 +339,7 @@ class CreateWebFormWizard(FormTemplate):
       # TODO: add simple trigger script
 
     if obj._type=='GFEntry':
-      outp+="entry = new GFEntry(page);\n" 
+      outp+="entry = new GFEntry(page);\n"
       outp+="entry._setParent(page);\n"
       outp+="entry.name='%s';\n" % obj.name
       outp+="entry.block='%s';\n" % obj.block
@@ -363,16 +363,16 @@ class CreateWebFormWizard(FormTemplate):
       ## Foreign key (f. dropdown) support
       if hasattr(obj,'fk_source'):
         outp+="entry.fk_source='%s';\n" % obj.fk_source
-        
+
       if hasattr(obj,'fk_key'):
         outp+="entry.fk_key='%s';\n" % obj.fk_key
-        
+
       if hasattr(obj,'fk_description'):
         outp+="entry.fk_descripion=%s';\n" % obj.fk_description
       outp+='\n'
 
 
-      
+
     if obj._type=='GFOption':
       pass
 
@@ -381,7 +381,7 @@ class CreateWebFormWizard(FormTemplate):
 
     if obj._type=="GFForm":
       outp+='}\n</script>\n'
-      
+
     return outp
 
   def addBackground(self):
@@ -389,13 +389,13 @@ class CreateWebFormWizard(FormTemplate):
            'top: %spx;' % self.yBase +\
            'left: %spx;\n' % self.xBase +\
            'width: %spx;' % (self.Xsize*self.Xraster) +\
-           'height: %spx;' % (self.Ysize*self.Yraster) +\
+           'height: %spx;\n' % (self.Ysize*self.Yraster) +\
            'border-width: 1px;'+\
-           'border-style: solid;background-color:#EEEEEE;" align="center">\n'
+           'border-style: solid;\nbackground-color:#EEEEEE;" align="center">\n'
     outp+='&nbsp;'
-    outp+='</DIV>'      
+    outp+='</DIV>'
     return outp
-    
+
   def addPageTab(self,name,pos):
     # outp = '<center><br><img src="img/gnue.png"><br></center>'
     outp='<DIV STYLE="position:absolute; '+\
@@ -407,7 +407,7 @@ class CreateWebFormWizard(FormTemplate):
            'border-style: solid;background-color:#EEEEEE;"\n' +\
            'align="center" onclick="getForm().gotoPage(' +\
            "'%s');" % name + '">\n'
-    outp+='%s' % name   
+    outp+='%s' % name
     outp+='</DIV>'
     return outp
 
@@ -415,7 +415,7 @@ class CreateWebFormWizard(FormTemplate):
     b='<img src="images/'+img+'-24x24.png" name="'+name+'" alt="'+alt+\
        '" onclick="'+ command+';">\n';
     return b
-    
+
   def addButtonBar(self):
     # outp = '<center><br><img src="img/gnue.png"><br></center>'
     outp='<DIV STYLE="position:absolute; '+\
@@ -423,8 +423,8 @@ class CreateWebFormWizard(FormTemplate):
            'left: %spx;\n' % (max([self.Xsize*self.Xraster,540])/2+self.xBase-270) +\
            'width: %spx;' % 540 +\
            'border-width: 1px;'+\
-           'border-style: solid;background-color:#EEEEEE;" align="center">\n'
-      
+           'border-style: solid;\nbackground-color:#EEEEEE;" align="center">\n'
+
     self.yBase=self.yBase+50
 
     outp+=self.showButton('commit',"commit","Commit","getForm().commit();",'n')
@@ -473,29 +473,29 @@ class CreateWebFormWizard(FormTemplate):
       # compute max/min
       if obj.Char__x+obj.Char__width>self.Xsize:
         self.Xsize=int(obj.Char__x+obj.Char__width+1)
-	
+
       if obj.Char__y+obj.Char__height>self.Ysize:
         self.Ysize=int(obj.Char__y+obj.Char__height+1)
 
     for child in obj._children:
       self.computePageSize(child)
-      
-        
+
+
   # function build the html code for page
   def drawElements(self,obj,visible):
 
     outp=""
-    
+
     if ((obj._type=='GFEntry') or (obj._type=='GFLabel') or \
         (obj._type=='GFButton') or (obj._type=='GFBox')) and not obj.hidden:
-        
+
       pos_code='STYLE="position:absolute; '+\
                 'top: %spx;' % int(obj.Char__y*self.Yraster+self.yBase) +\
                 'left: %spx;' % int(obj.Char__x*self.Xraster+self.xBase) +\
                 'width: %spx;' % int(obj.Char__width*self.Xraster) +\
-                'height: %spx;' % int(obj.Char__height*self.Yraster-self.baseline)
+                'height: %spx;\n  ' % int(obj.Char__height*self.Yraster-self.baseline)
 
-      if visible==0: 
+      if visible==0:
 	pos_code+='visibility:hidden;'
 
       if obj._type=='GFLabel':
@@ -504,6 +504,9 @@ class CreateWebFormWizard(FormTemplate):
       else:
         pos_code+='font-size: %spx;' % int(self.fontsize_entry)
 
+      if obj._type=='GFEntry':
+        pos_code+='background: #F6F6F6;'
+
       if obj._type=='GFBox':
         pos_code+='border-width: 1px; border-style: solid;"'
       else:
@@ -511,21 +514,21 @@ class CreateWebFormWizard(FormTemplate):
 
       # TODO: add loop for row setting
       if obj._type=='GFEntry':
-        # TODO: add dropdown, height 
+        # TODO: add dropdown, height
         outp+='\n\n  <!-- Entry %s -->\n' % obj.name
         if obj.style=="password":
           outp+='  <input type="password"'
         elif obj.style=="dropdown":
-          outp+='  <select'        
+          outp+='  <select'
 	  print "ATTENTION: creating dropdown widgets which are not supported by the javascript client yet!"
         elif obj.Char__height>1:
           outp+='  <textarea'
         else:
           outp+='  <input type="text"'
-          
-        outp+=' name="%s" id="%s_%s_field" ' % (obj.name,obj.block,obj.field)
-        
-        outp+='onfocus="getForm().gotoBlock('+"'%s'" % obj.block +\
+
+        outp+=' name="%s"\n  id="%s_%s_field" ' % (obj.name,obj.block,obj.field)
+
+        outp+='\n  onfocus="getForm().gotoBlock('+"'%s'" % obj.block +\
                ');"\n';
 
         outp+=pos_code;
@@ -539,29 +542,29 @@ class CreateWebFormWizard(FormTemplate):
           outp+='>%s</textarea>\n' % obj.default
         else:
           outp+='value="%s">\n' % obj.default
-          
-        
+
+
       elif obj._type=='GFLabel':
-        outp+='  <!-- Label %s -->\n' % obj.name
+        outp+='\n  <!-- Label %s -->\n' % obj.name
         outp+='  <DIV %s id="%s_label">%s</DIV>\n' %\
                (pos_code,obj.name,obj.text)
-        
+
       elif obj._type=='GFButton':
-        outp+='  <!-- Button %s -->\n' % obj.name
+        outp+='\n  <!-- Button %s -->\n' % obj.name
         outp+='  <button %s id="%s_button">%s</button>\n' % \
                (pos_code,obj.name,obj.label)
 
       elif obj._type=='GFBox':
-        outp+='  <!-- Box %s -->\n' % obj.name
+        outp+='\n  <!-- Box %s -->\n' % obj.name
         outp+='  <div %s id="%s_box">%s</div>\n' % \
                (pos_code,obj.name,obj.label)
 
-        
+
 
     for child in obj._children:
       outp+=self.drawElements(child,visible)
 
-    return outp   
+    return outp
 
   def addLoginDialog(self):
     outp='<DIV STYLE="position:absolute; '+\
@@ -577,9 +580,9 @@ class CreateWebFormWizard(FormTemplate):
     outp+='Password: <INPUT type="password" id="password"><BR><BR>\n'
     outp+='<BUTTON onClick="getForm().doLogin();">Login</BUTTON>\n</DIV>\n'
     return outp;
-   
 
-      
+
+
 
 ############
 #
@@ -589,12 +592,12 @@ TemplateInformation = {
     'Product': 'forms',
     'BaseID' : 'CreateWebForm',
     'BaseClass' : CreateWebFormWizard,
-    'Name' : 'Compile Form for GNUe JsForms',
-    'Description' : 'create a intermediate html+java for the jsForms client',
+    'Name' : _('Compile Form for GNUe JsForms'),
+    'Description' : _('Create an intermediate html+java for the jsForms client'),
     'Version' : VERSION,
     'Author' : 'The GNUe Designer Team',
     'Behavior': WIZARD,
-    'MenuLocation' : ('Tools|Extras',_('Compile Form for GNUe JsForms'))
+    'MenuLocation' : (_('Tools|Extras'),_('Compile Form for GNUe JsForms'))
 }
 
 if __name__ == "__main__":
