@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # FILE:
 # Simple.py
@@ -352,6 +352,7 @@ class FormBuilderTemplate(FormTemplate):
   # No more user input is allowed at this point.
   #
   def Finalize(self):
+    self.instance.wizardName = TemplateInformation['Name']
 
     logic = self.current['logic']
     layout = self.current['layout']
@@ -464,11 +465,11 @@ class FormBuilderTemplate(FormTemplate):
                 'field': field.name,
                 'typecast': field.datatype }
 
-        # If we have a length for the field, use this as the max_length
+        # If we have a length for the field, use this as the maxLength
         # for the entry. Also, adjust the display width if necessary.
         if hasattr(field,'length'):
-          ln = max(min(field.length, 25),0) or 10 
-          attrs['max_length'] = ln
+          ln = max(min(field.length, 40),0) or 10 
+          attrs['maxLength'] = ln
           largestField = max(largestField, ln)
         else:
           largestField = max(largestField, 10)
@@ -504,7 +505,7 @@ class FormBuilderTemplate(FormTemplate):
 
           # If label width is larger than entry width, center the entry
           try:
-            entryWidth = min(field['max_length'],25)
+            entryWidth = min(field['maxLength'],40)
           except KeyError:
             entryWidth = 10
           if entryWidth < textLen:
@@ -582,10 +583,10 @@ class FormBuilderTemplate(FormTemplate):
                'Char:y': y,
                'Char:width': 10 }
 
-        # If we have a length for the field, use this as the max_length
+        # If we have a length for the field, use this as the maxLength
         # for the entry. Also, adjust the display width if necessary.
         try:
-          attrs['Char:width'] = min(field['max_length'], 25)
+          attrs['Char:width'] = min(field['maxLength'], 40)
         except KeyError:
           pass
 
